Author: mseidel
Date: Tue Jun 11 12:06:28 2019
New Revision: 1861030

URL: http://svn.apache.org/viewvc?rev=1861030&view=rev
Log:
Merged r1860845 and r1860851 from trunk

Fixed typos (wether -> whether)
Fixed typos (determins-> determines)

Modified:
    openoffice/branches/AOO42X/   (props changed)
    openoffice/branches/AOO42X/main/canvas/inc/canvas/rendering/isurface.hxx
    openoffice/branches/AOO42X/main/canvas/source/directx/dx_surfacebitmap.hxx
    
openoffice/branches/AOO42X/main/chart2/source/controller/drawinglayer/DrawViewWrapper.cxx
    
openoffice/branches/AOO42X/main/chart2/source/controller/main/ChartController_Window.cxx
    
openoffice/branches/AOO42X/main/chart2/source/controller/main/PositionAndSizeHelper.cxx
    
openoffice/branches/AOO42X/main/chart2/source/controller/main/SelectionHelper.cxx
    
openoffice/branches/AOO42X/main/chart2/source/inc/chartview/ExplicitScaleValues.hxx
    openoffice/branches/AOO42X/main/chart2/source/model/main/ChartModel.cxx
    
openoffice/branches/AOO42X/main/chart2/source/model/main/ChartModel_Persistence.cxx
    openoffice/branches/AOO42X/main/chart2/source/tools/AxisHelper.cxx
    openoffice/branches/AOO42X/main/chart2/source/tools/LifeTime.cxx
    openoffice/branches/AOO42X/main/chart2/source/view/axes/VAxisProperties.hxx
    openoffice/branches/AOO42X/main/chart2/source/view/charttypes/BarChart.cxx
    openoffice/branches/AOO42X/main/chart2/source/view/charttypes/BarChart.hxx
    
openoffice/branches/AOO42X/main/chart2/source/view/charttypes/VSeriesPlotter.cxx
    openoffice/branches/AOO42X/main/chart2/source/view/inc/VCoordinateSystem.hxx
    openoffice/branches/AOO42X/main/chart2/source/view/inc/VDataSeries.hxx
    openoffice/branches/AOO42X/main/chart2/source/view/inc/VSeriesPlotter.hxx
    openoffice/branches/AOO42X/main/chart2/source/view/main/ChartView.cxx
    openoffice/branches/AOO42X/main/chart2/source/view/main/ChartView.hxx
    openoffice/branches/AOO42X/main/chart2/source/view/main/Clipping.cxx
    
openoffice/branches/AOO42X/main/chart2/source/view/main/PolarLabelPositionHelper.cxx
    openoffice/branches/AOO42X/main/chart2/source/view/main/VLegend.cxx
    openoffice/branches/AOO42X/main/configure.ac
    openoffice/branches/AOO42X/main/connectivity/java/dbtools/build.xml
    openoffice/branches/AOO42X/main/connectivity/java/sdbc_hsqldb/build.xml
    openoffice/branches/AOO42X/main/connectivity/java/sdbc_jdbc/build.xml
    openoffice/branches/AOO42X/main/connectivity/java/sdbc_postgresql/build.xml
    openoffice/branches/AOO42X/main/cui/source/inc/dlgname.hxx
    openoffice/branches/AOO42X/main/cui/source/options/optdict.cxx
    
openoffice/branches/AOO42X/main/dbaccess/source/ui/app/subcomponentmanager.cxx
    
openoffice/branches/AOO42X/main/editeng/source/accessibility/AccessibleEditableTextPara.cxx
    openoffice/branches/AOO42X/main/io/test/stm/pumptest.cxx
    
openoffice/branches/AOO42X/main/jurt/java/jurt/src/main/java/com/sun/star/comp/servicemanager/ServiceManager.java
    openoffice/branches/AOO42X/main/l10ntools/java/jpropex/build.xml
    openoffice/branches/AOO42X/main/l10ntools/java/l10nconv/build.xml
    
openoffice/branches/AOO42X/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java
    openoffice/branches/AOO42X/main/l10ntools/java/receditor/build.xml
    openoffice/branches/AOO42X/main/l10ntools/source/tagtest.cxx
    openoffice/branches/AOO42X/main/linguistic/workben/sspellimp.cxx
    
openoffice/branches/AOO42X/main/odk/examples/DevelopersGuide/Forms/ComponentTreeTraversal.java
    openoffice/branches/AOO42X/main/offapi/com/sun/star/chart/XAxisSupplier.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/Axis.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/DataSeries.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/IncrementData.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/ScaleData.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/XCoordinateSystem.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/drawing/framework/XConfiguration.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/report/ReportPrintOption.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/report/XReportControlFormat.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/report/XSection.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/style/CharacterProperties.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/style/PageProperties.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/style/ParagraphProperties.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/BaseFrameProperties.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/CellProperties.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/CellRange.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/ContentIndex.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/DocumentIndex.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/DocumentIndexMark.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/FontEmphasis.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/FontRelief.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/NumberingRules.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/SizeType.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextFieldMaster.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextGraphicObject.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextPageStyle.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextSection.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextTable.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/UserDefinedIndex.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/UserIndex.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XNumberingTypeInfo.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XPagePrintable.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XTextTableCursor.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/Bibliography.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/DDE.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/SetExpression.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/User.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Chapter.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Database.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/DatabaseNextSet.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/DatabaseNumberOfSet.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/FileName.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/GetExpression.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/JumpEdit.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/PageNumber.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/ReferencePageSet.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Script.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/SetExpression.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/TableFormula.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/TemplateName.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/User.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ActionTriggerSeparator.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ActionTriggerSeparatorType.idl
    
openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ContextMenuInterceptorAction.idl
    openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ItemType.idl
    
openoffice/branches/AOO42X/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs
    
openoffice/branches/AOO42X/main/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs
    openoffice/branches/AOO42X/main/psprint_config/configuration/psprint.conf
    openoffice/branches/AOO42X/main/pyuno/inc/pyuno/pyuno.hxx
    openoffice/branches/AOO42X/main/reportdesign/source/core/sdr/UndoEnv.cxx
    openoffice/branches/AOO42X/main/sal/osl/os2/file_url.cxx
    openoffice/branches/AOO42X/main/sal/osl/os2/pipeimpl.h
    openoffice/branches/AOO42X/main/sal/osl/unx/thread.c
    openoffice/branches/AOO42X/main/sal/osl/w32/file_url.cxx
    openoffice/branches/AOO42X/main/sal/osl/w32/pipeimpl.h
    openoffice/branches/AOO42X/main/sd/source/ui/app/sdmod1.cxx
    openoffice/branches/AOO42X/main/sd/source/ui/dlg/TemplateScanner.cxx
    openoffice/branches/AOO42X/main/sd/source/ui/dlg/dlgass.cxx
    openoffice/branches/AOO42X/main/sd/source/ui/func/fupage.cxx
    
openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/cache/SlsQueueProcessorThread.hxx
    
openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/inc/view/SlsButtonBar.hxx
    
openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/inc/view/SlsInsertAnimator.hxx
    
openoffice/branches/AOO42X/main/sdext/source/pdfimport/tree/writertreevisiting.cxx
    openoffice/branches/AOO42X/main/sfx2/qa/complex/sfx2/DocumentInfo.java
    
openoffice/branches/AOO42X/main/sfx2/qa/complex/sfx2/GlobalEventBroadcaster.java
    openoffice/branches/AOO42X/main/sfx2/source/appl/appopen.cxx
    openoffice/branches/AOO42X/main/sfx2/source/control/dispatch.cxx
    openoffice/branches/AOO42X/main/sfx2/source/dialog/filedlghelper.cxx
    openoffice/branches/AOO42X/main/sfx2/source/doc/docinsert.cxx
    openoffice/branches/AOO42X/main/sfx2/source/doc/doctempl.cxx
    openoffice/branches/AOO42X/main/sfx2/source/doc/doctemplates.cxx
    openoffice/branches/AOO42X/main/sfx2/source/view/ipclient.cxx
    openoffice/branches/AOO42X/main/sfx2/source/view/viewfrm.cxx
    openoffice/branches/AOO42X/main/shell/source/unix/exec/shellexec.cxx
    
openoffice/branches/AOO42X/main/svx/source/accessibility/ChildrenManagerImpl.cxx
    
openoffice/branches/AOO42X/main/svx/source/accessibility/ChildrenManagerImpl.hxx
    openoffice/branches/AOO42X/main/svx/source/form/fmundo.cxx
    openoffice/branches/AOO42X/main/sw/source/core/doc/htmltbl.cxx
    openoffice/branches/AOO42X/main/sw/source/core/text/pormulti.hxx
    openoffice/branches/AOO42X/main/sw/source/ui/inc/swuiidxmrk.hxx
    openoffice/branches/AOO42X/main/sw/source/ui/index/swuiidxmrk.cxx
    openoffice/branches/AOO42X/main/tools/inc/tools/debug.hxx
    
openoffice/branches/AOO42X/main/ucb/source/cacher/cachedcontentresultsetstub.cxx
    openoffice/branches/AOO42X/main/unotools/source/ucbhelper/ucblockbytes.cxx
    openoffice/branches/AOO42X/main/vcl/inc/vcl/fontmanager.hxx
    openoffice/branches/AOO42X/main/vcl/inc/vcl/outdev.hxx
    openoffice/branches/AOO42X/main/vcl/source/window/window.cxx
    openoffice/branches/AOO42X/main/vcl/unx/generic/app/saldata.cxx
    openoffice/branches/AOO42X/main/vcl/unx/generic/app/saldisp.cxx
    openoffice/branches/AOO42X/main/vcl/unx/generic/dtrans/X11_selection.cxx
    openoffice/branches/AOO42X/main/vcl/unx/generic/fontmanager/fontmanager.cxx
    openoffice/branches/AOO42X/main/vcl/unx/generic/gdi/salprnpsp.cxx
    openoffice/branches/AOO42X/main/vcl/unx/generic/printergfx/psheader.ps
    openoffice/branches/AOO42X/main/vcl/unx/headless/svpprn.cxx
    
openoffice/branches/AOO42X/main/wizards/com/sun/star/wizards/ui/SortingComponent.java
    openoffice/branches/AOO42X/main/wizards/source/tools/Misc.xba
    openoffice/branches/AOO42X/main/xmerge/source/inc/antbuild.properties
    openoffice/branches/AOO42X/main/xmerge/workben/build.xml
    openoffice/branches/AOO42X/main/xmloff/source/chart/SchXMLChartContext.hxx
    openoffice/branches/AOO42X/main/xmloff/source/meta/xmlversion.cxx
    openoffice/branches/AOO42X/main/xmloff/source/style/styleexp.cxx

Propchange: openoffice/branches/AOO42X/
------------------------------------------------------------------------------
--- svn:mergeinfo (original)
+++ svn:mergeinfo Tue Jun 11 12:06:28 2019
@@ -9,4 +9,4 @@
 /openoffice/branches/ia2:1417739-1541842
 
/openoffice/branches/ooxml-osba:1546391,1546395,1546574,1546934,1547030,1547392,1551920,1551954,1551958,1552283
 
/openoffice/branches/rejuvenate01:1480411,1534063,1534098,1536312,1549902,1560617
-/openoffice/trunk:1851110-1851111,1851115,1851118,1851121,1851206,1851214-1851215,1851443,1851449,1851464,1851575,1851634,1851637,1851639,1851715,1851753,1851813,1851987,1852008,1852010,1852029,1852046,1852174,1852187,1852190,1852197,1852430,1852438,1852623-1852624,1852841,1852965,1853175,1853245,1853252,1853285-1853286,1853299,1853319,1853327,1853443-1853444,1853456,1853466,1853504,1853558,1853643,1853668,1853670,1853726,1853742,1853972,1853976,1854051,1854065,1854176,1854196,1854324-1854325,1854473,1854519,1854740,1854788,1854852,1854933,1855053,1855140,1855181,1855246,1855509,1855523,1855617,1855647,1855649,1855778,1855813,1855926,1855947,1856034,1856079,1856113,1856224,1856555,1856677,1856833,1856899,1857186,1857302,1857311,1857450-1857451,1857877-1857878,1857899-1857900,1858000,1858167,1858209,1858284,1858381-1858382,1858505,1858511,1858682,1858700,1858940,1858942,1858949,1859148,1859223,1859362-1859363,1859486,1859491,1859582,1859636,1859657,1859668,1859685,1859827,1859839,186
 
0288,1860381,1860383,1860448,1860636,1860664,1860680,1860684,1860690,1860707,1860718
+/openoffice/trunk:1851110-1851111,1851115,1851118,1851121,1851206,1851214-1851215,1851443,1851449,1851464,1851575,1851634,1851637,1851639,1851715,1851753,1851813,1851987,1852008,1852010,1852029,1852046,1852174,1852187,1852190,1852197,1852430,1852438,1852623-1852624,1852841,1852965,1853175,1853245,1853252,1853285-1853286,1853299,1853319,1853327,1853443-1853444,1853456,1853466,1853504,1853558,1853643,1853668,1853670,1853726,1853742,1853972,1853976,1854051,1854065,1854176,1854196,1854324-1854325,1854473,1854519,1854740,1854788,1854852,1854933,1855053,1855140,1855181,1855246,1855509,1855523,1855617,1855647,1855649,1855778,1855813,1855926,1855947,1856034,1856079,1856113,1856224,1856555,1856677,1856833,1856899,1857186,1857302,1857311,1857450-1857451,1857877-1857878,1857899-1857900,1858000,1858167,1858209,1858284,1858381-1858382,1858505,1858511,1858682,1858700,1858940,1858942,1858949,1859148,1859223,1859362-1859363,1859486,1859491,1859582,1859636,1859657,1859668,1859685,1859827,1859839,186
 
0288,1860381,1860383,1860448,1860636,1860664,1860680,1860684,1860690,1860707,1860718,1860845,1860851

Modified: 
openoffice/branches/AOO42X/main/canvas/inc/canvas/rendering/isurface.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/canvas/inc/canvas/rendering/isurface.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/canvas/inc/canvas/rendering/isurface.hxx 
(original)
+++ openoffice/branches/AOO42X/main/canvas/inc/canvas/rendering/isurface.hxx 
Tue Jun 11 12:06:28 2019
@@ -49,7 +49,7 @@ namespace canvas
          */
                virtual bool selectTexture() = 0;
 
-               /** Tells wether the surface is valid or not
+               /** Tells whether the surface is valid or not
                */
                virtual bool isValid() = 0;
 

Modified: 
openoffice/branches/AOO42X/main/canvas/source/directx/dx_surfacebitmap.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/canvas/source/directx/dx_surfacebitmap.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/canvas/source/directx/dx_surfacebitmap.hxx 
(original)
+++ openoffice/branches/AOO42X/main/canvas/source/directx/dx_surfacebitmap.hxx 
Tue Jun 11 12:06:28 2019
@@ -127,7 +127,7 @@ namespace dxcanvas
         // internal implementation of the iColorBuffer interface
         canvas::IColorBufferSharedPtr mpColorBuffer;
 
-        // indicates wether the associated surface needs
+        // indicates whether the associated surface needs
         // to refresh its contents or not. in other words,
         // this flag is set iff both representations are
         // out of sync.

Modified: 
openoffice/branches/AOO42X/main/chart2/source/controller/drawinglayer/DrawViewWrapper.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/controller/drawinglayer/DrawViewWrapper.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/chart2/source/controller/drawinglayer/DrawViewWrapper.cxx
 (original)
+++ 
openoffice/branches/AOO42X/main/chart2/source/controller/drawinglayer/DrawViewWrapper.cxx
 Tue Jun 11 12:06:28 2019
@@ -281,7 +281,7 @@ void DrawViewWrapper::MarkObject( SdrObj
     if( m_pMarkHandleProvider )
         bFrameDragSingles = m_pMarkHandleProvider->getFrameDragSingles();
 
-       this->SetFrameDragSingles(bFrameDragSingles);//decide wether each 
single object should get handles
+       this->SetFrameDragSingles(bFrameDragSingles);//decide whether each 
single object should get handles
     this->SdrView::MarkObj( pObj, this->GetPageView() );
     this->showMarkHandles();
 }

Modified: 
openoffice/branches/AOO42X/main/chart2/source/controller/main/ChartController_Window.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/controller/main/ChartController_Window.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/chart2/source/controller/main/ChartController_Window.cxx
 (original)
+++ 
openoffice/branches/AOO42X/main/chart2/source/controller/main/ChartController_Window.cxx
 Tue Jun 11 12:06:28 2019
@@ -246,7 +246,7 @@ const short HITPIX=2; //hit-tolerance in
         Size aLogicSize = m_pChartWindow->PixelToLogic( Size( Width, Height ), 
MapMode( MAP_100TH_MM )  );
 
         bool bIsEmbedded = true;
-        //todo: for standalone chart: detect wether we are standalone
+        //todo: for standalone chart: detect whether we are standalone
         if( bIsEmbedded )
         {
             //change map mode to fit new size

Modified: 
openoffice/branches/AOO42X/main/chart2/source/controller/main/PositionAndSizeHelper.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/controller/main/PositionAndSizeHelper.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/chart2/source/controller/main/PositionAndSizeHelper.cxx
 (original)
+++ 
openoffice/branches/AOO42X/main/chart2/source/controller/main/PositionAndSizeHelper.cxx
 Tue Jun 11 12:06:28 2019
@@ -58,7 +58,7 @@ bool PositionAndSizeHelper::moveObject(
 
     if( OBJECTTYPE_TITLE==eObjectType )
     {
-        //@todo decide wether x is primary or secondary
+        //@todo decide whether x is primary or secondary
         chart2::RelativePosition aRelativePosition;
         aRelativePosition.Anchor = drawing::Alignment_CENTER;
         //the anchor point at the title object is top/middle
@@ -69,7 +69,7 @@ bool PositionAndSizeHelper::moveObject(
     }
     else if( OBJECTTYPE_DATA_CURVE_EQUATION==eObjectType )
     {
-        //@todo decide wether x is primary or secondary
+        //@todo decide whether x is primary or secondary
         chart2::RelativePosition aRelativePosition;
         aRelativePosition.Anchor = drawing::Alignment_TOP_LEFT;
         //the anchor point at the title object is top/middle
@@ -110,7 +110,7 @@ bool PositionAndSizeHelper::moveObject(
     }
     else if(OBJECTTYPE_DIAGRAM==eObjectType || 
OBJECTTYPE_DIAGRAM_WALL==eObjectType || OBJECTTYPE_DIAGRAM_FLOOR==eObjectType)
     {
-        //@todo decide wether x is primary or secondary
+        //@todo decide whether x is primary or secondary
 
         //set position:
         chart2::RelativePosition aRelativePosition;

Modified: 
openoffice/branches/AOO42X/main/chart2/source/controller/main/SelectionHelper.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/controller/main/SelectionHelper.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/chart2/source/controller/main/SelectionHelper.cxx
 (original)
+++ 
openoffice/branches/AOO42X/main/chart2/source/controller/main/SelectionHelper.cxx
 Tue Jun 11 12:06:28 2019
@@ -271,7 +271,7 @@ void Selection::adaptSelectionToNewPos(
                     m_aSelectedOID = ObjectIdentifier( aPageCID );
                 }
 
-                //check wether the diagram was hit but not selected (e.g. 
because it has no filling):
+                //check whether the diagram was hit but not selected (e.g. 
because it has no filling):
                 rtl::OUString aDiagramCID = 
ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DIAGRAM, 
rtl::OUString::valueOf( sal_Int32(0) ) );
                 rtl::OUString aWallCID( 
ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DIAGRAM_WALL, 
rtl::OUString() ) );//@todo read CID from model
                 bool bBackGroundHit = m_aSelectedOID.getObjectCID().equals( 
aPageCID ) || m_aSelectedOID.getObjectCID().equals( aWallCID ) || 
!m_aSelectedOID.isAutoGeneratedObject();
@@ -288,7 +288,7 @@ void Selection::adaptSelectionToNewPos(
                         }
                     }
                 }
-                //check wether the legend was hit but not selected (e.g. 
because it has no filling):
+                //check whether the legend was hit but not selected (e.g. 
because it has no filling):
                 if( bBackGroundHit || m_aSelectedOID.getObjectCID().equals( 
aDiagramCID ) )
                 {
                     rtl::OUString aLegendCID( 
ObjectIdentifier::createClassifiedIdentifierForParticle( 
ObjectIdentifier::createParticleForLegend(0,0) ) );//@todo read CID from model
@@ -561,7 +561,7 @@ SdrObject* SelectionHelper::getObjectToM
 
 E3dScene* SelectionHelper::getSceneToRotate( SdrObject* pObj )
 {
-    //search wether the object or one of its children is a 3D object
+    //search whether the object or one of its children is a 3D object
     //if so, return the accessory 3DScene
     
     E3dObject* pRotateable = 0;

Modified: 
openoffice/branches/AOO42X/main/chart2/source/inc/chartview/ExplicitScaleValues.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/inc/chartview/ExplicitScaleValues.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/chart2/source/inc/chartview/ExplicitScaleValues.hxx
 (original)
+++ 
openoffice/branches/AOO42X/main/chart2/source/inc/chartview/ExplicitScaleValues.hxx
 Tue Jun 11 12:06:28 2019
@@ -108,13 +108,13 @@ struct OOO_DLLPUBLIC_CHARTVIEW ExplicitI
     before a scaling is applied, which may lead to non equidistant tickmarks
     on the screen.</p>
 
-    <p><member>PostEquidistant</member> rules wether the 
<member>Distance</member>
+    <p><member>PostEquidistant</member> rules whether the 
<member>Distance</member>
     is meant to be a value before or after scaling.</p>
     */
        double          Distance;
 
     /**
-    <member>PostEquidistant</member> rules wether the member 
<member>Distance</member>
+    <member>PostEquidistant</member> rules whether the member 
<member>Distance</member>
     describes a distance before or after the scaling is applied.
 
     <p>If <member>PostEquidistant</member> equals <TRUE/> 
<member>Distance</member>

Modified: 
openoffice/branches/AOO42X/main/chart2/source/model/main/ChartModel.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/model/main/ChartModel.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/chart2/source/model/main/ChartModel.cxx 
(original)
+++ openoffice/branches/AOO42X/main/chart2/source/model/main/ChartModel.cxx Tue 
Jun 11 12:06:28 2019
@@ -632,7 +632,7 @@ void SAL_CALL ChartModel::close( sal_Boo
     uno::Reference< uno::XInterface > xSelfHold( static_cast< 
::cppu::OWeakObject* >(this) );
 
        //the listeners have had no veto
-       //check wether we self can close
+       //check whether we self can close
        {
                util::CloseVetoException aVetoException = 
util::CloseVetoException(
                                                ::rtl::OUString( 
RTL_CONSTASCII_USTRINGPARAM(

Modified: 
openoffice/branches/AOO42X/main/chart2/source/model/main/ChartModel_Persistence.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/model/main/ChartModel_Persistence.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/chart2/source/model/main/ChartModel_Persistence.cxx
 (original)
+++ 
openoffice/branches/AOO42X/main/chart2/source/model/main/ChartModel_Persistence.cxx
 Tue Jun 11 12:06:28 2019
@@ -257,7 +257,7 @@ void SAL_CALL ChartModel::store()
 
        if( aLocation.isEmpty() )
                throw io::IOException( C2U( "no location specified" ), 
static_cast< ::cppu::OWeakObject* >(this));
-       //@todo check wether aLocation is something like private:factory...
+       //@todo check whether aLocation is something like private:factory...
        if( m_bReadOnly )
                throw io::IOException( C2U( "document is read only" ), 
static_cast< ::cppu::OWeakObject* >(this));
 

Modified: openoffice/branches/AOO42X/main/chart2/source/tools/AxisHelper.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/tools/AxisHelper.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/chart2/source/tools/AxisHelper.cxx 
(original)
+++ openoffice/branches/AOO42X/main/chart2/source/tools/AxisHelper.cxx Tue Jun 
11 12:06:28 2019
@@ -159,7 +159,7 @@ sal_Int32 AxisHelper::getExplicitNumberF
     if( xProp.is() && !( xProp->getPropertyValue( C2U( "NumberFormat" ) ) >>= 
nNumberFormatKey ) )
     {
         bool bFormatSet = false;
-        //check wether we have a percent scale -> use percent format
+        //check whether we have a percent scale -> use percent format
         if( xNumberFormatsSupplier.is() )
         {
             ScaleData aData = AxisHelper::getDateCheckedScale( xAxis, 
Reference< frame::XModel >( xNumberFormatsSupplier, uno::UNO_QUERY ) );

Modified: openoffice/branches/AOO42X/main/chart2/source/tools/LifeTime.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/tools/LifeTime.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/configure.ac (original)
+++ openoffice/branches/AOO42X/main/configure.ac Tue Jun 11 12:06:28 2019
@@ -4519,7 +4519,7 @@ if test "x$enable_coinmp" = "xyes"; then
     AC_MSG_RESULT([yes])
     ENABLE_COINMP=YES
 
-    dnl Check wether to use system or internal CoinMP
+    dnl Check whether to use system or internal CoinMP
     AC_MSG_CHECKING([which coinmp to use])
     if test "x$with_system_coinmp" = "xyes" -o -n "$with_system_libs"; then
         AC_MSG_RESULT([system])

Modified: openoffice/branches/AOO42X/main/connectivity/java/dbtools/build.xml
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/connectivity/java/dbtools/build.xml?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/connectivity/java/dbtools/build.xml 
(original)
+++ openoffice/branches/AOO42X/main/connectivity/java/dbtools/build.xml Tue Jun 
11 12:06:28 2019
@@ -84,13 +84,13 @@
     <!-- set "modern" java compiler -->
     <property name="build.compiler" value="modern"/>
 
-    <!-- set wether we want to compile with debug information -->
+    <!-- set whether we want to compile with debug information -->
     <property name="debug" value="on"/>
 
-    <!-- set wether we want to compile with optimisation -->
+    <!-- set whether we want to compile with optimisation -->
     <property name="optimize" value="off"/>
 
-    <!-- set wether we want to compile with or without deprecation -->
+    <!-- set whether we want to compile with or without deprecation -->
     <property name="deprecation" value="on"/>
 
     <target name="info">

Modified: 
openoffice/branches/AOO42X/main/connectivity/java/sdbc_hsqldb/build.xml
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/connectivity/java/sdbc_hsqldb/build.xml?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/connectivity/java/sdbc_hsqldb/build.xml 
(original)
+++ openoffice/branches/AOO42X/main/connectivity/java/sdbc_hsqldb/build.xml Tue 
Jun 11 12:06:28 2019
@@ -78,13 +78,13 @@
     <!-- set "modern" java compiler -->
     <property name="build.compiler" value="modern"/>
 
-    <!-- set wether we want to compile with debug information -->
+    <!-- set whether we want to compile with debug information -->
     <property name="debug" value="on"/>
 
-    <!-- set wether we want to compile with optimisation -->
+    <!-- set whether we want to compile with optimisation -->
     <property name="optimize" value="off"/>
 
-    <!-- set wether we want to compile with or without deprecation -->
+    <!-- set whether we want to compile with or without deprecation -->
     <property name="deprecation" value="on"/>
 
     <target name="info">

Modified: openoffice/branches/AOO42X/main/connectivity/java/sdbc_jdbc/build.xml
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/connectivity/java/sdbc_jdbc/build.xml?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/connectivity/java/sdbc_jdbc/build.xml 
(original)
+++ openoffice/branches/AOO42X/main/connectivity/java/sdbc_jdbc/build.xml Tue 
Jun 11 12:06:28 2019
@@ -85,13 +85,13 @@
     <!-- set "modern" java compiler -->
     <property name="build.compiler" value="modern"/>
 
-    <!-- set wether we want to compile with debug information -->
+    <!-- set whether we want to compile with debug information -->
     <property name="debug" value="on"/>
 
-    <!-- set wether we want to compile with optimisation -->
+    <!-- set whether we want to compile with optimisation -->
     <property name="optimize" value="off"/>
 
-    <!-- set wether we want to compile with or without deprecation -->
+    <!-- set whether we want to compile with or without deprecation -->
     <property name="deprecation" value="on"/>
 
     <target name="info">

Modified: 
openoffice/branches/AOO42X/main/connectivity/java/sdbc_postgresql/build.xml
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/connectivity/java/sdbc_postgresql/build.xml?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/connectivity/java/sdbc_postgresql/build.xml 
(original)
+++ openoffice/branches/AOO42X/main/connectivity/java/sdbc_postgresql/build.xml 
Tue Jun 11 12:06:28 2019
@@ -77,13 +77,13 @@
     <!-- set "modern" java compiler -->
     <property name="build.compiler" value="modern"/>
 
-    <!-- set wether we want to compile with debug information -->
+    <!-- set whether we want to compile with debug information -->
     <property name="debug" value="on"/>
 
-    <!-- set wether we want to compile with optimisation -->
+    <!-- set whether we want to compile with optimisation -->
     <property name="optimize" value="off"/>
 
-    <!-- set wether we want to compile with or without deprecation -->
+    <!-- set whether we want to compile with or without deprecation -->
     <property name="deprecation" value="on"/>
 
     <target name="info">

Modified: openoffice/branches/AOO42X/main/cui/source/inc/dlgname.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/cui/source/inc/dlgname.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/cui/source/inc/dlgname.hxx (original)
+++ openoffice/branches/AOO42X/main/cui/source/inc/dlgname.hxx Tue Jun 11 
12:06:28 2019
@@ -66,7 +66,7 @@ public:
     void    GetName( String& rName ){rName = aEdtName.GetText();}
 
     /** add a callback Link that is called whenever the content of the edit
-        field is changed.  The Link result determines wether the OK
+        field is changed.  The Link result determines whether the OK
         Button is enabled (> 0) or disabled (== 0).
 
         @param rLink a Callback declared with DECL_LINK and implemented with

Modified: openoffice/branches/AOO42X/main/cui/source/options/optdict.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/cui/source/options/optdict.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/cui/source/options/optdict.cxx (original)
+++ openoffice/branches/AOO42X/main/cui/source/options/optdict.cxx Tue Jun 11 
12:06:28 2019
@@ -616,7 +616,7 @@ IMPL_LINK(SvxEditDictionaryDialog, NewDe
                        {
                                // make changes in dic
 
-                               //! ...IsVisible should reflect wether the 
dictionary is a negativ
+                               //! ...IsVisible should reflect whether the 
dictionary is a negativ
                                //! or not (hopefully...)
                                sal_Bool bIsNegEntry = aReplaceFT.IsVisible();
                                ::rtl::OUString aRplcText;

Modified: 
openoffice/branches/AOO42X/main/dbaccess/source/ui/app/subcomponentmanager.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/dbaccess/source/ui/app/subcomponentmanager.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/dbaccess/source/ui/app/subcomponentmanager.cxx 
(original)
+++ 
openoffice/branches/AOO42X/main/dbaccess/source/ui/app/subcomponentmanager.cxx 
Tue Jun 11 12:06:28 2019
@@ -165,7 +165,7 @@ namespace dbaui
                         xController.set( xFrame->getController(), 
UNO_SET_THROW );
                     }
 
-                    // check wether there is a model (not required)
+                    // check whether there is a model (not required)
                     xModel.set( xController->getModel() );
                 }
 

Modified: 
openoffice/branches/AOO42X/main/editeng/source/accessibility/AccessibleEditableTextPara.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/editeng/source/accessibility/AccessibleEditableTextPara.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/editeng/source/accessibility/AccessibleEditableTextPara.cxx
 (original)
+++ 
openoffice/branches/AOO42X/main/editeng/source/accessibility/AccessibleEditableTextPara.cxx
 Tue Jun 11 12:06:28 2019
@@ -758,7 +758,7 @@ namespace accessibility
             !pStateSet->contains(nStateId) )
         {
             pStateSet->AddState( nStateId );
-               // MT: Removed method IsShapeParaFocusable which was introduced 
with IA2 - basically it was only about figuring out wether or not the window 
has the focus, should be solved differently
+               // MT: Removed method IsShapeParaFocusable which was introduced 
with IA2 - basically it was only about figuring out whether or not the window 
has the focus, should be solved differently
                // if(IsShapeParaFocusable())
             GotPropertyEvent( uno::makeAny( nStateId ), 
AccessibleEventId::STATE_CHANGED );
         }

Modified: openoffice/branches/AOO42X/main/io/test/stm/pumptest.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/io/test/stm/pumptest.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/io/test/stm/pumptest.cxx (original)
+++ openoffice/branches/AOO42X/main/io/test/stm/pumptest.cxx Tue Jun 11 
12:06:28 2019
@@ -377,7 +377,7 @@ void OPumpTest::testTerminate( const Ref
     ERROR_ASSERT( t.m_pTestListener->m_bStarted , "should have been started 
already" );
     ERROR_ASSERT( t.m_pTestListener->m_bTerminated , "should be terminiated 
already" );
     // terminte leads to an error, that is no surprise, in fact
-    // one can't tell wether the error occurs because of the terminate
+    // one can't tell whether the error occurs because of the terminate
     // call or for some other reason !
 //     ERROR_ASSERT( ! t.m_pTestListener->m_bError, "unexpected error" );
     ERROR_ASSERT( t.m_pTestListener->m_bClosed, "should be closed already" );

Modified: 
openoffice/branches/AOO42X/main/jurt/java/jurt/src/main/java/com/sun/star/comp/servicemanager/ServiceManager.java
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/jurt/java/jurt/src/main/java/com/sun/star/comp/servicemanager/ServiceManager.java?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/jurt/java/jurt/src/main/java/com/sun/star/comp/servicemanager/ServiceManager.java
 (original)
+++ 
openoffice/branches/AOO42X/main/jurt/java/jurt/src/main/java/com/sun/star/comp/servicemanager/ServiceManager.java
 Tue Jun 11 12:06:28 2019
@@ -837,7 +837,7 @@ class ServiceManagerFactory implements
     }
 
        /**
-        * Checks wether or not a service is supported.
+        * Checks whether or not a service is supported.
         * <p>
         * @return              true - if the service is supported, otherwise 
false.
         * @param               serviceName             the name of the service 
that should be checked.

Modified: openoffice/branches/AOO42X/main/l10ntools/java/jpropex/build.xml
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/l10ntools/java/jpropex/build.xml?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/l10ntools/java/jpropex/build.xml (original)
+++ openoffice/branches/AOO42X/main/l10ntools/java/jpropex/build.xml Tue Jun 11 
12:06:28 2019
@@ -62,13 +62,13 @@
     <!-- set "modern" java compiler -->
     <property name="build.compiler" value="modern"/>
 
-    <!-- set wether we want to compile with debug information -->
+    <!-- set whether we want to compile with debug information -->
     <property name="debug" value="on"/>
 
-    <!-- set wether we want to compile with optimisation -->
+    <!-- set whether we want to compile with optimisation -->
     <property name="optimize" value="off"/>
 
-    <!-- set wether we want to compile with or without deprecation -->
+    <!-- set whether we want to compile with or without deprecation -->
     <property name="deprecation" value="on"/>
 
     <target name="info">

Modified: openoffice/branches/AOO42X/main/l10ntools/java/l10nconv/build.xml
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/l10ntools/java/l10nconv/build.xml?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/l10ntools/java/l10nconv/build.xml (original)
+++ openoffice/branches/AOO42X/main/l10ntools/java/l10nconv/build.xml Tue Jun 
11 12:06:28 2019
@@ -62,13 +62,13 @@
     <!-- set "modern" java compiler -->
     <property name="build.compiler" value="modern"/>
 
-    <!-- set wether we want to compile with debug information -->
+    <!-- set whether we want to compile with debug information -->
     <property name="debug" value="on"/>
 
-    <!-- set wether we want to compile with optimisation -->
+    <!-- set whether we want to compile with optimisation -->
     <property name="optimize" value="off"/>
 
-    <!-- set wether we want to compile with or without deprecation -->
+    <!-- set whether we want to compile with or without deprecation -->
     <property name="deprecation" value="on"/>
 
     <target name="info">

Modified: 
openoffice/branches/AOO42X/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java
 (original)
+++ 
openoffice/branches/AOO42X/main/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/FileMaker.java
 Tue Jun 11 12:06:28 2019
@@ -45,7 +45,7 @@ public final class FileMaker {
      * ask if existing files should be overwritten
      * 
      * @param fileName the files name to overwrite
-     * @param overwrite indicates wether the file can be overwritten
+     * @param overwrite indicates whether the file can be overwritten
      * @return the File created from the fileName
      * @throws IOException
      */

Modified: openoffice/branches/AOO42X/main/l10ntools/java/receditor/build.xml
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/l10ntools/java/receditor/build.xml?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/l10ntools/java/receditor/build.xml 
(original)
+++ openoffice/branches/AOO42X/main/l10ntools/java/receditor/build.xml Tue Jun 
11 12:06:28 2019
@@ -62,13 +62,13 @@
     <!-- set "modern" java compiler -->
     <property name="build.compiler" value="modern"/>
 
-    <!-- set wether we want to compile with debug information -->
+    <!-- set whether we want to compile with debug information -->
     <property name="debug" value="on"/>
 
-    <!-- set wether we want to compile with optimisation -->
+    <!-- set whether we want to compile with optimisation -->
     <property name="optimize" value="off"/>
 
-    <!-- set wether we want to compile with or without deprecation -->
+    <!-- set whether we want to compile with or without deprecation -->
     <property name="deprecation" value="on"/>
 
     <target name="info">

Modified: openoffice/branches/AOO42X/main/l10ntools/source/tagtest.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/l10ntools/source/tagtest.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/l10ntools/source/tagtest.cxx (original)
+++ openoffice/branches/AOO42X/main/l10ntools/source/tagtest.cxx Tue Jun 11 
12:06:28 2019
@@ -447,7 +447,7 @@ sal_Bool TokenInfo::MatchesTranslation(
 {
     // check if tags are equal
     // check if all existing properties are in the translation as well and
-    // wether they have a matching content (the same in most cases)
+    // whether they have a matching content (the same in most cases)
 
     if ( nId != rInfo.nId )
         return sal_False;

Modified: openoffice/branches/AOO42X/main/linguistic/workben/sspellimp.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/linguistic/workben/sspellimp.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/linguistic/workben/sspellimp.cxx (original)
+++ openoffice/branches/AOO42X/main/linguistic/workben/sspellimp.cxx Tue Jun 11 
12:06:28 2019
@@ -134,7 +134,7 @@ sal_Bool SAL_CALL SpellChecker::hasLocal
 
 INT16 SpellChecker::GetSpellFailure( const OUString &rWord, const Locale 
&rLocale )
 {
-       // Checks wether a word is OK in a given language (Locale) or not, and
+       // Checks whether a word is OK in a given language (Locale) or not, and
        // provides a failure type for the incorrect ones.
        // - words with "liss" (case sensitiv) as substring will be negative.
        // - words with 'x' or 'X' will have incorrect spelling.

Modified: 
openoffice/branches/AOO42X/main/odk/examples/DevelopersGuide/Forms/ComponentTreeTraversal.java
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/odk/examples/DevelopersGuide/Forms/ComponentTreeTraversal.java?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/odk/examples/DevelopersGuide/Forms/ComponentTreeTraversal.java
 (original)
+++ 
openoffice/branches/AOO42X/main/odk/examples/DevelopersGuide/Forms/ComponentTreeTraversal.java
 Tue Jun 11 12:06:28 2019
@@ -39,7 +39,7 @@ interface IFormComponentAction
 class ComponentTreeTraversal implements IFormComponentAction
 {
        /* ------------------------------------------------------------------ */
-       /** Indicator method to decide wether to step down the tree.
+       /** Indicator method to decide whether to step down the tree.
 
                <p>The default implementation checks if the container given is 
a grid
                control model or a <service 
scope="com.sun.star.form">FormComponents</service>

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/chart/XAxisSupplier.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/chart/XAxisSupplier.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/chart/XAxisSupplier.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/chart/XAxisSupplier.idl 
Tue Jun 11 12:06:28 2019
@@ -39,7 +39,7 @@ interface XAxisSupplier : ::com::sun::st
                the primary axis of the specified dimension. The returned 
object supports service <type>ChartAxis</type>.
 
         @param nDimensionIndex
-            Parameter nDimensionIndex says wether it is a x, y or z-axis (0 
for x).
+            Parameter nDimensionIndex says whether it is a x, y or z-axis (0 
for x).
         */
        com::sun::star::chart::XAxis getAxis( [in] long nDimensionIndex );
 
@@ -47,7 +47,7 @@ interface XAxisSupplier : ::com::sun::st
                the secondary axis of the specified dimension. The returned 
object supports service <type>ChartAxis</type>.
 
         @param nDimensionIndex
-            Parameter nDimensionIndex says wether it is a x, y or z-axis (0 
for x).
+            Parameter nDimensionIndex says whether it is a x, y or z-axis (0 
for x).
         */
     com::sun::star::chart::XAxis getSecondaryAxis( [in] long nDimensionIndex );
 };

Modified: openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/Axis.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/Axis.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/Axis.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/Axis.idl Tue Jun 
11 12:06:28 2019
@@ -83,15 +83,15 @@ service Axis
     */
     [property]      ::com::sun::star::chart::ChartAxisArrangeOrderType 
ArrangeOrder;
 
-    /** Determines wether the labels are allowed to break into more than one 
line
+    /** Determines whether the labels are allowed to break into more than one 
line
     */
     [property]      boolean   TextBreak;
 
-    /** Determines wether the labels are allowed to overlap
+    /** Determines whether the labels are allowed to overlap
     */
     [property]      boolean   TextOverlap;
 
-    /** Determines wether the characters in a single labels should be stacked 
one upon each other
+    /** Determines whether the characters in a single labels should be stacked 
one upon each other
     */
     [property]      boolean   StackCharacters;
 

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/DataSeries.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/DataSeries.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/DataSeries.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/DataSeries.idl 
Tue Jun 11 12:06:28 2019
@@ -159,7 +159,7 @@ service DataSeries
      */
     [readonly, optional, property] sequence< long > AttributedDataPoints;
 
-    /** indicates wether this series should be stacked with respect to the 
previous series.
+    /** indicates whether this series should be stacked with respect to the 
previous series.
     */
     [property] StackingDirection StackingDirection;
 
@@ -168,7 +168,7 @@ service DataSeries
      */
     [optional, property] boolean                    VaryColorsByPoint;
 
-    /** This property describes wether the series should be shown at
+    /** This property describes whether the series should be shown at
         the main value axis or at the secondary value axis.  Having
         this property not set or setting it to 0 means that this data
         series will be scaled at the primary y-axis ( of the

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/IncrementData.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/IncrementData.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/IncrementData.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/IncrementData.idl 
Tue Jun 11 12:06:28 2019
@@ -48,7 +48,7 @@ struct IncrementData
     any         Distance;
 
     /**
-    <member>PostEquidistant</member> rules wether the member 
<member>Distance</member>
+    <member>PostEquidistant</member> rules whether the member 
<member>Distance</member>
     describes a distance before or after the scaling is applied.
 
     <p>If <member>PostEquidistant</member> equals <TRUE/> 
<member>Distance</member>

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/ScaleData.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/ScaleData.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/ScaleData.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/ScaleData.idl 
Tue Jun 11 12:06:28 2019
@@ -93,7 +93,7 @@ struct ScaleData
     */
     boolean AutoDateAxis;
 
-    /** describes wether data points on category or date axis are placed 
between tickmarks or not
+    /** describes whether data points on category or date axis are placed 
between tickmarks or not
     if true the maximum on the scale will be expanded for one interval
     */
     boolean ShiftedCategoryPosition;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/XCoordinateSystem.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/XCoordinateSystem.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/XCoordinateSystem.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/chart2/XCoordinateSystem.idl
 Tue Jun 11 12:06:28 2019
@@ -59,8 +59,8 @@ interface XCoordinateSystem : ::com::sun
     */
     string getViewServiceName();
 
-    /** The dimension says wether it is a x, y or z axis.
-        The index says wether it is a primary or a secondary axis.
+    /** The dimension says whether it is a x, y or z axis.
+        The index says whether it is a primary or a secondary axis.
         Use nIndex == 0 for a primary axis.
      */
     void setAxisByDimension( [in] long nDimension,
@@ -68,8 +68,8 @@ interface XCoordinateSystem : ::com::sun
                               [in] long nIndex )
         raises( com::sun::star::lang::IndexOutOfBoundsException );
 
-    /** The dimension says wether it is a x, y or z axis.
-        The index indicates wether it is a primary or a secondary axis or 
maybe more in future.
+    /** The dimension says whether it is a x, y or z axis.
+        The index indicates whether it is a primary or a secondary axis or 
maybe more in future.
         Use nIndex == 0 for a primary axis.
         An empty Reference will be returned if the given nDimension and nIndex 
are in the valid range but no axis is set for those values.
         An IndexOutOfBoundsException will be thrown if nDimension is lower 
than 0 or greater than the value returned by getDimension()

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/drawing/framework/XConfiguration.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/drawing/framework/XConfiguration.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/drawing/framework/XConfiguration.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/drawing/framework/XConfiguration.idl
 Tue Jun 11 12:06:28 2019
@@ -86,7 +86,7 @@ published interface XConfiguration
         [in] string sTargetURLPrefix,
         [in] AnchorBindingMode eSearchMode);
 
-    /** <p>Returns wether the specified resource is part of the
+    /** <p>Returns whether the specified resource is part of the
         configuration.</p>
         This is independent of whether the resource does really exist and is
         active, i.e. has a visible representation in the GUI.

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/report/ReportPrintOption.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/report/ReportPrintOption.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/report/ReportPrintOption.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/report/ReportPrintOption.idl
 Tue Jun 11 12:06:28 2019
@@ -30,7 +30,7 @@
 
 //=============================================================================
 
-/** Specifies wether a page header or footer is printed on the same page as 
the report header or report footer.
+/** Specifies whether a page header or footer is printed on the same page as 
the report header or report footer.
  */
 published constants ReportPrintOption
 {

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/report/XReportControlFormat.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/report/XReportControlFormat.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/report/XReportControlFormat.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/report/XReportControlFormat.idl
 Tue Jun 11 12:06:28 2019
@@ -110,7 +110,7 @@ published interface XReportControlFormat
         get raises ( com::sun::star::beans::UnknownPropertyException );
     };
 
-    /** determins whether text is formatted in two lines.
+    /** determines whether text is formatted in two lines.
      <p>It is linked to the properties CharCombinePrefix and 
CharCombineSuffix.</p>
      */
     [attribute,bound] boolean CharCombineIsOn
@@ -351,7 +351,7 @@ published interface XReportControlFormat
     };
 
     //-------------------------------------------------------------------------
-    /**        determins the type of the strike out of the character.
+    /**        determines the type of the strike out of the character.
         @see com::sun::star::awt::FontStrikeout
     */
     [attribute,bound] short CharStrikeout
@@ -369,7 +369,7 @@ published interface XReportControlFormat
         get raises ( com::sun::star::beans::UnknownPropertyException );
     };
 
-    /** determins the rotation of a character in degree.
+    /** determines the rotation of a character in degree.
         <p>Depending on the implementation only certain values may be allowed.
         </p>
      */
@@ -380,7 +380,7 @@ published interface XReportControlFormat
     };
     //-------------------------------------------------------------------------
 
-    /** determins the percentage value for scaling the width of characters.
+    /** determines the percentage value for scaling the width of characters.
 
         <p>The value refers to the original width which is denoted by 100,
         and it has to be greater than 0.</p>

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/report/XSection.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/report/XSection.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/report/XSection.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/report/XSection.idl Tue 
Jun 11 12:06:28 2019
@@ -114,7 +114,7 @@ published interface XSection
     */
     [attribute,bound] string ConditionalPrintExpression;
 
-    /** Specifies wether the section is printed on a separate page.
+    /** Specifies whether the section is printed on a separate page.
         <p>Not valid for page header or page footer.</p>
         @see ForceNewPage
     */
@@ -124,7 +124,7 @@ published interface XSection
         get raises ( com::sun::star::beans::UnknownPropertyException );
     };
 
-    /** Specifies wether the section is printed in a new row or column within 
a multi column report.
+    /** Specifies whether the section is printed in a new row or column within 
a multi column report.
         <p>Not valid for page header or page footer.</p>
         @see ForceNewPage
     */

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/style/CharacterProperties.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/style/CharacterProperties.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/style/CharacterProperties.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/style/CharacterProperties.idl
 Tue Jun 11 12:06:28 2019
@@ -177,7 +177,7 @@ published service CharacterProperties
 
        
//-------------------------------------------------------------------------
 
-    /** This property determins the type of the strike out of the character.
+    /** This property determines the type of the strike out of the character.
         @see com::sun::star::awt::FontStrikeout
        */
        [optional, property] short CharStrikeout;
@@ -252,7 +252,7 @@ published service CharacterProperties
 
     //-------------------------------------------------------------------------
 
-    /** This optional property determins whether text is formatted in two 
lines.
+    /** This optional property determines whether text is formatted in two 
lines.
 
         <p>It is linked to the properties CharCombinePrefix and 
CharCombineSuffix.</p>
      */
@@ -298,7 +298,7 @@ published service CharacterProperties
 
     //-------------------------------------------------------------------------
 
-    /** This optional property determins the adjustment of the ruby .
+    /** This optional property determines the adjustment of the ruby .
         @see com::sun::star::text::RubyAdjust
      */
     [optional, property] short RubyAdjust;
@@ -312,14 +312,14 @@ published service CharacterProperties
 
     //-------------------------------------------------------------------------
 
-    /** This optional property determins whether the ruby text is printed
+    /** This optional property determines whether the ruby text is printed
         above/left or below/right of the text.
      */
     [optional, property] boolean RubyIsAbove;
 
     //-------------------------------------------------------------------------
 
-    /** This optional property determins the rotation of a character in tenths
+    /** This optional property determines the rotation of a character in tenths
         of a degree.
 
        <p>Depending on the implementation only certain values may be 
allowed.</p>
@@ -328,14 +328,14 @@ published service CharacterProperties
 
     //-------------------------------------------------------------------------
 
-    /** This optional property determins whether the text formatting tries to
+    /** This optional property determines whether the text formatting tries to
         fit rotated text into the surrounded line height.
      */
     [optional, property] boolean CharRotationIsFitToLine;
 
     //-------------------------------------------------------------------------
 
-    /** This optional property determins the percentage value for scaling the
+    /** This optional property determines the percentage value for scaling the
         width of characters.
 
         <p>The value refers to the original width which is denoted by 100,

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/style/PageProperties.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/style/PageProperties.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/style/PageProperties.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/style/PageProperties.idl 
Tue Jun 11 12:06:28 2019
@@ -90,30 +90,30 @@ published service PageProperties
  */
 [property] string BackGraphicFilter;
 //-----------------------------------------------------------------------------
-/** determins the location of the background graphic.
+/** determines the location of the background graphic.
  */
 [property] com::sun::star::style::GraphicLocation BackGraphicLocation;
 //-----------------------------------------------------------------------------
-/** determins if the background color is transparent.
+/** determines if the background color is transparent.
  
     <p>If this property is set to <TRUE/>,
     <member>PageStyle::BackColor</member> will not be used.</p>
  */
 [property] boolean BackTransparent;
 //-----------------------------------------------------------------------------
-/** determins the left margin of the page.
+/** determines the left margin of the page.
  */
 [property] long LeftMargin;
 //-----------------------------------------------------------------------------
-/** determins the right margin of the page.
+/** determines the right margin of the page.
  */
 [property] long RightMargin;
 //-----------------------------------------------------------------------------
-/** determins the top margin of the page.
+/** determines the top margin of the page.
  */
 [property] long TopMargin;
 //-----------------------------------------------------------------------------
-/** determins the bottom margin of the page.
+/** determines the bottom margin of the page.
  */
 [property] long BottomMargin;
 //-----------------------------------------------------------------------------
@@ -133,35 +133,35 @@ published service PageProperties
  */
 [property] com::sun::star::table::BorderLine BottomBorder;
 //-----------------------------------------------------------------------------
-/** determins the left border distance of the page.
+/** determines the left border distance of the page.
  */
 [property] long LeftBorderDistance;
 //-----------------------------------------------------------------------------
-/** determins the right border distance of the page.
+/** determines the right border distance of the page.
  */
 [property] long RightBorderDistance;
 //-----------------------------------------------------------------------------
-/** determins the top border distance of the page.
+/** determines the top border distance of the page.
  */
 [property] long TopBorderDistance;
 //-----------------------------------------------------------------------------
-/** determins the bottom border distance of the page.
+/** determines the bottom border distance of the page.
  */
 [property] long BottomBorderDistance;
 //-----------------------------------------------------------------------------
-/** determins the shadow of the page.
+/** determines the shadow of the page.
  */
 [property] com::sun::star::table::ShadowFormat ShadowFormat;
 //-----------------------------------------------------------------------------
-/** determins if the page format is landscape.
+/** determines if the page format is landscape.
  */
 [property] boolean IsLandscape;
 //-----------------------------------------------------------------------------
-/** determins the default numbering type for this page.
+/** determines the default numbering type for this page.
  */
 [property] short NumberingType;
 //-----------------------------------------------------------------------------
-/** determins the layout of the page.
+/** determines the layout of the page.
  */
 [property] com::sun::star::style::PageStyleLayout PageStyleLayout;
 //-----------------------------------------------------------------------------
@@ -169,7 +169,7 @@ published service PageProperties
  */
 [property] string PrinterPaperTray;
 //-----------------------------------------------------------------------------
-/** determins if the register mode is active on that page.
+/** determines if the register mode is active on that page.
  */
 [optional, property] boolean RegisterModeActive;
 //-----------------------------------------------------------------------------

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/style/ParagraphProperties.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/style/ParagraphProperties.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/style/ParagraphProperties.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/style/ParagraphProperties.idl
 Tue Jun 11 12:06:28 2019
@@ -361,7 +361,7 @@ published service ParagraphProperties
         [property, optional] long BottomBorderDistance;
 
        
//-------------------------------------------------------------------------
-        /** determins the type of break that is applied at the beginning of 
the table.
+        /** determines the type of break that is applied at the beginning of 
the table.
             @see com::sun::star::style::BreakType
          */
         [optional, property] com::sun::star::style::BreakType BreakType;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/BaseFrameProperties.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/BaseFrameProperties.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/BaseFrameProperties.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/BaseFrameProperties.idl
 Tue Jun 11 12:06:28 2019
@@ -203,11 +203,11 @@ published service BaseFrameProperties
         */
        [property] short RelativeWidth;
        
//-------------------------------------------------------------------------
-       /** determins whether the width follows the height.
+       /** determines whether the width follows the height.
         */
        [property] boolean IsSyncWidthToHeight;
        
//-------------------------------------------------------------------------
-       /** determins whether the height follows the width.
+       /** determines whether the height follows the width.
         */
        [property] boolean IsSyncHeightToWidth;
        
//-------------------------------------------------------------------------

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/CellProperties.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/CellProperties.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/CellProperties.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/CellProperties.idl 
Tue Jun 11 12:06:28 2019
@@ -94,7 +94,7 @@ published service CellProperties
     [property] string BackGraphicFilter;
     
     //-------------------------------------------------------------------------
-    /** determins the position of the background graphic.
+    /** determines the position of the background graphic.
         */
     [property] com::sun::star::style::GraphicLocation BackGraphicLocation;
     
@@ -104,7 +104,7 @@ published service CellProperties
     [property] long NumberFormat;
     
     //-------------------------------------------------------------------------
-    /** determins whether the background is transparent.
+    /** determines whether the background is transparent.
      */
     [property] boolean BackTransparent;
     
@@ -154,7 +154,7 @@ published service CellProperties
     [readonly, property]com::sun::star::text::XTextSection TextSection;
     
     //-------------------------------------------------------------------------
-    /** determins whether the cell is write protected or not.
+    /** determines whether the cell is write protected or not.
         */
     [property] boolean IsProtected;
 

Modified: openoffice/branches/AOO42X/main/offapi/com/sun/star/text/CellRange.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/CellRange.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/CellRange.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/CellRange.idl Tue 
Jun 11 12:06:28 2019
@@ -111,7 +111,7 @@ published service CellRange
 
     
//-----------------------------------------------------------------------------
 
-    /** determins the location of the background graphic.
+    /** determines the location of the background graphic.
      */
     [property] com::sun::star::style::GraphicLocation BackGraphicLocation;
 
@@ -123,20 +123,20 @@ published service CellRange
 
     
//-----------------------------------------------------------------------------
 
-    /** determins if the background color is transparent.
+    /** determines if the background color is transparent.
      */
     [property] boolean BackTransparent;
 
     
//-----------------------------------------------------------------------------
 
-    /** determins if the first column of the table should be treated as
+    /** determines if the first column of the table should be treated as
         axis labels when a chart is to be created.
      */
     [property] boolean ChartColumnAsLabel;
 
     
//-----------------------------------------------------------------------------
 
-    /** determins if the first row of the table should be treated as
+    /** determines if the first row of the table should be treated as
         axis labels when a chart is to be created.
      */
     [property] boolean ChartRowAsLabel;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/ContentIndex.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/ContentIndex.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/ContentIndex.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/ContentIndex.idl 
Tue Jun 11 12:06:28 2019
@@ -40,12 +40,12 @@ published service ContentIndex
        // DocMerge: empty anyway
        service  com::sun::star::text::BaseIndex; 
  
-       /** determins the depth of outline levels that are included into the 
content index.*/ 
+       /** determines the depth of outline levels that are included into the 
content index.*/ 
        
        /// @missing
        [optional, property] short Level; 
 
-       /** determins if the document index is created from outlines. 
+       /** determines if the document index is created from outlines. 
        */ 
        [optional, property] boolean CreateFromOutline; 
  


Reply via email to
--- openoffice/branches/AOO42X/main/chart2/source/tools/LifeTime.cxx (original)
+++ openoffice/branches/AOO42X/main/chart2/source/tools/LifeTime.cxx Tue Jun 11 
12:06:28 2019
@@ -503,7 +503,7 @@ the XCloseable::close method has to be i
     uno::Reference< uno::XInterface > xSelfHold( static_cast< 
::cppu::OWeakObject* >(this) );
 
        //the listeners have had no veto
        //check wether we self can close
        {
                util::CloseVetoException aVetoException = 
util::CloseVetoException(
                                                ::rtl::OUString( 
RTL_CONSTASCII_USTRINGPARAM(

Modified: 
openoffice/branches/AOO42X/main/chart2/source/view/axes/VAxisProperties.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/view/axes/VAxisProperties.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/chart2/source/view/axes/VAxisProperties.hxx 
(original)
+++ openoffice/branches/AOO42X/main/chart2/source/view/axes/VAxisProperties.hxx 
Tue Jun 11 12:06:28 2019
@@ -81,7 +81,7 @@ struct AxisLabelProperties
     double               fRotationAngleDegree;
 
     sal_Int32   nRhythm; //show only each nth label with n==nRhythm
-    bool        bRhythmIsFix; //states wether the given rhythm is fix or may 
be changed
+    bool        bRhythmIsFix; //states whether the given rhythm is fix or may 
be changed
 
     //methods:
     void init( const ::com::sun::star::uno::Reference<

Modified: 
openoffice/branches/AOO42X/main/chart2/source/view/charttypes/BarChart.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/view/charttypes/BarChart.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/chart2/source/view/charttypes/BarChart.cxx 
(original)
+++ openoffice/branches/AOO42X/main/chart2/source/view/charttypes/BarChart.cxx 
Tue Jun 11 12:06:28 2019
@@ -590,7 +590,7 @@ void BarChart::createShapes()
                             bDrawConnectionLines = false;
                         if( bDrawConnectionLines && pSeriesList->size()==1 )
                         {
                             //detect wether we have a stacked chart or not:
                             StackingDirection eDirection = 
pSeries->getStackingDirection();
                             if( eDirection  != StackingDirection_Y_STACKING )
                                 bDrawConnectionLines = false;

Modified: 
openoffice/branches/AOO42X/main/chart2/source/view/charttypes/BarChart.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/view/charttypes/BarChart.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/chart2/source/view/charttypes/BarChart.hxx 
(original)
+++ openoffice/branches/AOO42X/main/chart2/source/view/charttypes/BarChart.hxx 
Tue Jun 11 12:06:28 2019
@@ -75,7 +75,7 @@ private: //methods
                         , double fScaledLowerBarDepth, double 
fScaledUpperBarDepth, double fBaseValue
                         , BarPositionHelper* pPosHelper ) const;
 
-    virtual PlottingPositionHelper& getPlottingPositionHelper( sal_Int32 
nAxisIndex ) const;//nAxisIndex indicates wether the position belongs to the 
main axis ( nAxisIndex==0 ) or secondary axis ( nAxisIndex==1 )
+    virtual PlottingPositionHelper& getPlottingPositionHelper( sal_Int32 
nAxisIndex ) const;//nAxisIndex indicates whether the position belongs to the 
main axis ( nAxisIndex==0 ) or secondary axis ( nAxisIndex==1 )
 
     void adaptOverlapAndGapwidthForGroupBarsPerAxis();
 

Modified: 
openoffice/branches/AOO42X/main/chart2/source/view/charttypes/VSeriesPlotter.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/view/charttypes/VSeriesPlotter.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/chart2/source/view/charttypes/VSeriesPlotter.cxx
 (original)
+++ 
openoffice/branches/AOO42X/main/chart2/source/view/charttypes/VSeriesPlotter.cxx
 Tue Jun 11 12:06:28 2019
@@ -448,7 +448,7 @@ uno::Reference< drawing::XShape > VSerie
                 m_pShapeFactory->createGroup2D( 
this->getLabelsGroupShape(rDataSeries, xTarget)
                     , ObjectIdentifier::createPointCID( 
rDataSeries.getLabelCID_Stub(),nPointIndex ) ) );
 
         //check wether the label needs to be created and how:
         DataPointLabel* pLabel = rDataSeries.getDataPointLabelIfLabel( 
nPointIndex );
 
         if( !pLabel )
@@ -1117,7 +1117,7 @@ void VSeriesPlotter::createRegressionCur
         chart2::RelativePosition aRelativePosition;
         if( xEquationProperties->getPropertyValue( C2U("RelativePosition")) 
>>= aRelativePosition )
         {
             //@todo decide wether x is primary or secondary
             double fX = aRelativePosition.Primary*m_aPageReferenceSize.Width;
             double fY = 
aRelativePosition.Secondary*m_aPageReferenceSize.Height;
             aScreenPosition2D.X = static_cast< sal_Int32 >( 
::rtl::math::round( fX ));

Modified: 
openoffice/branches/AOO42X/main/chart2/source/view/inc/VCoordinateSystem.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/view/inc/VCoordinateSystem.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/chart2/source/view/inc/VCoordinateSystem.hxx 
(original)
+++ 
openoffice/branches/AOO42X/main/chart2/source/view/inc/VCoordinateSystem.hxx 
Tue Jun 11 12:06:28 2019
@@ -160,7 +160,7 @@ protected: //member
 
     rtl::OUString m_aCooSysParticle;
 
-    typedef std::pair< sal_Int32, sal_Int32 > tFullAxisIndex; //first index is 
the dimension, second index is the axis index that indicates wether this is a 
main or secondary axis
+    typedef std::pair< sal_Int32, sal_Int32 > tFullAxisIndex; //first index is 
the dimension, second index is the axis index that indicates whether this is a 
main or secondary axis
     
     //
     ::com::sun::star::uno::Reference<

Modified: openoffice/branches/AOO42X/main/chart2/source/view/inc/VDataSeries.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/view/inc/VDataSeries.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/chart2/source/view/inc/VDataSeries.hxx 
(original)
+++ openoffice/branches/AOO42X/main/chart2/source/view/inc/VDataSeries.hxx Tue 
Jun 11 12:06:28 2019
@@ -219,7 +219,7 @@ private: //member
 
     ::com::sun::star::chart2::StackingDirection     m_eStackingDirection;
 
-    sal_Int32               m_nAxisIndex;//indicates wether this is attached 
to a main or secondary axis
+    sal_Int32               m_nAxisIndex;//indicates whether this is attached 
to a main or secondary axis
 
     sal_Bool                m_bConnectBars;
 

Modified: 
openoffice/branches/AOO42X/main/chart2/source/view/inc/VSeriesPlotter.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/view/inc/VSeriesPlotter.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/chart2/source/view/inc/VSeriesPlotter.hxx 
(original)
+++ openoffice/branches/AOO42X/main/chart2/source/view/inc/VSeriesPlotter.hxx 
Tue Jun 11 12:06:28 2019
@@ -402,7 +402,7 @@ protected: //methods
         , const tPropertyNameMap& rMap
         , tPropertyNameValueMap* pOverwriteMap=0 );
 
-    virtual PlottingPositionHelper& getPlottingPositionHelper( sal_Int32 
nAxisIndex ) const;//nAxisIndex indicates wether the position belongs to the 
main axis ( nAxisIndex==0 ) or secondary axis ( nAxisIndex==1 )
+    virtual PlottingPositionHelper& getPlottingPositionHelper( sal_Int32 
nAxisIndex ) const;//nAxisIndex indicates whether the position belongs to the 
main axis ( nAxisIndex==0 ) or secondary axis ( nAxisIndex==1 )
 
     VDataSeries* getFirstSeries() const;
 

Modified: openoffice/branches/AOO42X/main/chart2/source/view/main/ChartView.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/view/main/ChartView.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/chart2/source/view/main/ChartView.cxx 
(original)
+++ openoffice/branches/AOO42X/main/chart2/source/view/main/ChartView.cxx Tue 
Jun 11 12:06:28 2019
@@ -455,7 +455,7 @@ VCoordinateSystem* lcl_getCooSysForPlott
     return 0;
 }
 
-typedef std::pair< sal_Int32, sal_Int32 > tFullAxisIndex; //first index is the 
dimension, second index is the axis index that indicates wether this is a main 
or secondary axis
+typedef std::pair< sal_Int32, sal_Int32 > tFullAxisIndex; //first index is the 
dimension, second index is the axis index that indicates whether this is a main 
or secondary axis
 typedef std::pair< VCoordinateSystem* , tFullAxisIndex > tFullCoordinateSystem;
 typedef std::map< VCoordinateSystem*, tFullAxisIndex > tCoordinateSystemMap;
     
@@ -1948,7 +1948,7 @@ awt::Rectangle ExplicitValueProvider::ad
         ExplicitValueProvider* pExplicitValueProvider = 
ExplicitValueProvider::getExplicitValueProvider(xChartView);
         if( pExplicitValueProvider )
         {
             //detect wether x axis points into x direction or not
             if( lcl_getPropertySwapXAndYAxis( ChartModelHelper::findDiagram( 
xChartModel ) ) )
             {
                 std::swap( xTitle_Height, xTitle_Width );
@@ -2015,7 +2015,7 @@ awt::Rectangle ExplicitValueProvider::su
         ExplicitValueProvider* pExplicitValueProvider = 
ExplicitValueProvider::getExplicitValueProvider(xChartView);
         if( pExplicitValueProvider )
         {
             //detect wether x axis points into x direction or not
             if( lcl_getPropertySwapXAndYAxis( ChartModelHelper::findDiagram( 
xChartModel ) ) )
             {
                 std::swap( xTitle_Height, xTitle_Width );
@@ -2113,7 +2113,7 @@ bool getAvailablePosAndSizeForDiagram(
     chart2::RelativePosition aRelativePosition;
     if( xProp.is() && (xProp->getPropertyValue( C2U( "RelativePosition" ) 
)>>=aRelativePosition) )
     {
         //@todo decide wether x is primary or secondary
 
         //the coordinates re relative to the page
         double fX = aRelativePosition.Primary*rPageSize.Width;
@@ -2244,7 +2244,7 @@ std::auto_ptr<VTitle> lcl_createTitle( T
         {
             rbAutoPosition = false;
 
             //@todo decide wether x is primary or secondary
             double fX = aRelativePosition.Primary*rPageSize.Width;
             double fY = aRelativePosition.Secondary*rPageSize.Height;
 

Modified: openoffice/branches/AOO42X/main/chart2/source/view/main/ChartView.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/view/main/ChartView.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/chart2/source/view/main/ChartView.hxx 
(original)
+++ openoffice/branches/AOO42X/main/chart2/source/view/main/ChartView.hxx Tue 
Jun 11 12:06:28 2019
@@ -230,7 +230,7 @@ private: //member
     ::cppu::OMultiTypeInterfaceContainerHelper
                         m_aListenerContainer;
 
-    bool volatile       m_bViewDirty; //states wether the view needs to be 
rebuild
+    bool volatile       m_bViewDirty; //states whether the view needs to be 
rebuild
     bool volatile       m_bInViewUpdate;
     bool volatile       m_bViewUpdatePending;
     bool volatile              m_bRefreshAddIn;       

Modified: openoffice/branches/AOO42X/main/chart2/source/view/main/Clipping.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/view/main/Clipping.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/chart2/source/view/main/Clipping.cxx 
(original)
+++ openoffice/branches/AOO42X/main/chart2/source/view/main/Clipping.cxx Tue 
Jun 11 12:06:28 2019
@@ -110,7 +110,7 @@ bool lcl_clip2d(B2DTuple& rPoint0, B2DTu
                double fTE = 0,
                           fTL = 1;
                                
-               //      Test wether at least a part lies in the four 
half-planes with respect to 
+               //      Test whether at least a part lies in the four 
half-planes with respect to 
                //      the rectangles four edges.
                if( lcl_CLIPt(aDirection.getX(), rRectangle.getMinX() - 
rPoint0.getX(), fTE, fTL) )
                        if( lcl_CLIPt(-aDirection.getX(), rPoint0.getX() - 
rRectangle.getMaxX(), fTE, fTL) )

Modified: 
openoffice/branches/AOO42X/main/chart2/source/view/main/PolarLabelPositionHelper.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/view/main/PolarLabelPositionHelper.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/chart2/source/view/main/PolarLabelPositionHelper.cxx
 (original)
+++ 
openoffice/branches/AOO42X/main/chart2/source/view/main/PolarLabelPositionHelper.cxx
 Tue Jun 11 12:06:28 2019
@@ -91,7 +91,7 @@ awt::Point PolarLabelPositionHelper::get
     
     if(3==m_nDimensionCount && nLabelPlacement == 
::com::sun::star::chart::DataLabelPlacement::OUTSIDE)
     {
-        //check wether the upper or the downer edge is more distant from the 
center
+        //check whether the upper or the downer edge is more distant from the 
center
         //take the farest point to put the label to
 
         awt::Point aP0( this->transformSceneToScreenPosition(

Modified: openoffice/branches/AOO42X/main/chart2/source/view/main/VLegend.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/chart2/source/view/main/VLegend.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/chart2/source/view/main/VLegend.cxx 
(original)
+++ openoffice/branches/AOO42X/main/chart2/source/view/main/VLegend.cxx Tue Jun 
11 12:06:28 2019
@@ -375,7 +375,7 @@ awt::Size lcl_placeLegendEntries(
                 nCurrentColumn++;
                 if( nCurrentColumn < nCurrentColumnCount )
                 {
-                    //check wether the current column width is sufficient for 
the new entry
+                    //check whether the current column width is sufficient for 
the new entry
                     if( aColumnWidths[nCurrentColumn]>=nNewWidth )
                     {
@@ -503,7 +503,7 @@ the XCloseable::close method has to be i
 
        //the listeners have had no veto
-       //check wether we self can close
+       //check whether we self can close
        {
                util::CloseVetoException aVetoException = 
@@ -590,7 +590,7 @@ void BarChart::createShapes()
                         if( bDrawConnectionLines && pSeriesList->size()==1 )
                         {
-                            //detect wether we have a stacked chart or not:
+                            //detect whether we have a stacked chart or not:
                             StackingDirection eDirection = 
pSeries->getStackingDirection();
@@ -448,7 +448,7 @@ uno::Reference< drawing::XShape > VSerie
rDataSeries.getLabelCID_Stub(),nPointIndex ) ) );
 
-        //check wether the label needs to be created and how:
+        //check whether the label needs to be created and how:
         DataPointLabel* pLabel = rDataSeries.getDataPointLabelIfLabel( 
nPointIndex );
@@ -1117,7 +1117,7 @@ void VSeriesPlotter::createRegressionCur
>>= aRelativePosition )
         {
-            //@todo decide wether x is primary or secondary
+            //@todo decide whether x is primary or secondary
             double fX = aRelativePosition.Primary*m_aPageReferenceSize.Width;
             double fY = 
@@ -1948,7 +1948,7 @@ awt::Rectangle ExplicitValueProvider::ad
         if( pExplicitValueProvider )
         {
-            //detect wether x axis points into x direction or not
+            //detect whether x axis points into x direction or not
             if( lcl_getPropertySwapXAndYAxis( ChartModelHelper::findDiagram( 
xChartModel ) ) )
@@ -2015,7 +2015,7 @@ awt::Rectangle ExplicitValueProvider::su
         if( pExplicitValueProvider )
         {
-            //detect wether x axis points into x direction or not
+            //detect whether x axis points into x direction or not
             if( lcl_getPropertySwapXAndYAxis( ChartModelHelper::findDiagram( 
xChartModel ) ) )
@@ -2113,7 +2113,7 @@ bool getAvailablePosAndSizeForDiagram(
)>>=aRelativePosition) )
     {
-        //@todo decide wether x is primary or secondary
+        //@todo decide whether x is primary or secondary
 
         //the coordinates re relative to the page
@@ -2244,7 +2244,7 @@ std::auto_ptr<VTitle> lcl_createTitle( T
             rbAutoPosition = false;
 
-            //@todo decide wether x is primary or secondary
+            //@todo decide whether x is primary or secondary
             double fX = aRelativePosition.Primary*rPageSize.Width;
             double fY = aRelativePosition.Secondary*rPageSize.Height;
                         //all good proceed with next entry

Modified: openoffice/branches/AOO42X/main/configure.ac
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/configure.ac?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================